Touch Surgery Publisher Tools
=============================

To install for development purposes first make a virtualenv

    virtualenv tspub

Activate it 

    source tspub/bin/activate

Then install the package in editable mode with development dependencies

    pip install -e .[development]
